[][src]Struct debug_probe::flash::download::FileDownloader

pub struct FileDownloader;

This struct and impl bundle functionality to start the Downloader which then will flash the given data to the flash of the target.

Supported file formats are:

  • Binary (.bin)
  • Intel Hex (.hex)
  • ELF (.elf or .axf)

Methods

impl<'a> FileDownloader[src]

pub fn new() -> Self[src]

pub fn download_file(
    self,
    session: &mut Session,
    path: &Path,
    format: Format,
    memory_map: &Vec<MemoryRegion>
) -> Result<(), FileDownloadError>
[src]

Downloads a file at path into flash.