[−][src]Struct debug_probe::flash::flasher::FlashAlgorithm
Fields
load_address: u32Memory address where the flash algo instructions will be loaded to.
instructions: &'static [u32]List of 32-bit words containing the position-independant code for the algo.
pc_init: Option<u32>Address of the Init() entry point. Optional.
pc_uninit: Option<u32>Address of the UnInit() entry point. Optional.
pc_program_page: u32Address of the ProgramPage() entry point.
pc_erase_sector: u32Address of the EraseSector() entry point.
pc_erase_all: Option<u32>Address of the EraseAll() entry point. Optional.
static_base: u32Initial value of the R9 register for calling flash algo entry points, which determines where the position-independant data resides.
begin_stack: u32Initial value of the stack pointer when calling any flash algo API.
begin_data: u32Base address of the page buffer. Used if page_buffers is not provided.
page_buffers: &'static [u32]An optional list of base addresses for page buffers. The buffers must be at least as large as the region's page_size attribute. If at least 2 buffers are included in the list, then double buffered programming will be enabled.
min_program_length: Option<u32>analyzer_supported: boolWhether the CRC32-based analyzer is supported.
analyzer_address: u32RAM base address where the analyzer code will be placed. There must be at least 0x600 free bytes after this address.