[−][src]Module debug_probe::flash::loader
Structs
| FlashLoader | Handles high level programming of raw binary data to flash. |
| Ranges |
Enums
| FlashLoaderError |
Functions
| ranges | Accepts a sorted list of byte addresses. Breaks the addresses into contiguous ranges. Yields 2-tuples of the start and end address for each contiguous range. For instance, the input [0, 1, 2, 3, 32, 33, 34, 35] will yield the following 2-tuples: (0, 3) and (32, 35). |